translate.storage.lisa

Package translate :: Package storage :: Module lisa |
[hide private]
[frames] | no frames]

# Module lisa

source code

Parent class for LISA standards (TMX, TBX, XLIFF)

Classes | [hide private]
| LISAunit A single unit in the file.
| LISAfile A class representing a file store for one of the LISA file formats.

Variables | [hide private]
| __package__ = ``'``translate.storage``'``

Imports: re, etree, getText, getXMLlang, setXMLlang, getXMLspace, setXMLspace, namespaced, base, data